==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/AWSPrivateLinkInventoryBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AWSPrivateLinkInventoryBuilder extends AWSPrivateLinkInventoryFluentImpl<AWSPrivateLinkInventoryBuilder> implements VisitableBuilder<AWSPrivateLinkInventory,AWSPrivateLinkInventoryBuilder>{
  public AWSPrivateLinkInventoryBuilder() {
    this(false);
  }
  public AWSPrivateLinkInventoryBuilder(Boolean validationEnabled) {
    this(new AWSPrivateLinkInventory(), validationEnabled);
  }
  public AWSPrivateLinkInventoryBuilder(AWSPrivateLinkInventoryFluent<?> fluent) {
    this(fluent, false);
  }
  public AWSPrivateLinkInventoryBuilder(AWSPrivateLinkInventoryFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AWSPrivateLinkInventory(), validationEnabled);
  }
  public AWSPrivateLinkInventoryBuilder(AWSPrivateLinkInventoryFluent<?> fluent,AWSPrivateLinkInventory instance) {
    this(fluent, instance, false);
  }
  public AWSPrivateLinkInventoryBuilder(AWSPrivateLinkInventoryFluent<?> fluent,AWSPrivateLinkInventory instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withRegion(instance.getRegion());
      fluent.withSubnets(instance.getSubnets());
      fluent.withVpcID(instance.getVpcID());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AWSPrivateLinkInventoryBuilder(AWSPrivateLinkInventory instance) {
    this(instance,false);
  }
  public AWSPrivateLinkInventoryBuilder(AWSPrivateLinkInventory instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withRegion(instance.getRegion());
      this.withSubnets(instance.getSubnets());
      this.withVpcID(instance.getVpcID());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AWSPrivateLinkInventoryFluent<?> fluent;
  Boolean validationEnabled;
  public AWSPrivateLinkInventory build() {
    AWSPrivateLinkInventory buildable = new AWSPrivateLinkInventory(fluent.getRegion(),fluent.getSubnets(),fluent.getVpcID());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/AWSPrivateLinkInventoryBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AWSPrivateLinkInventoryBuilder extends AWSPrivateLinkInventoryFluent<AWSPrivateLinkInventoryBuilder> implements VisitableBuilder<AWSPrivateLinkInventory,AWSPrivateLinkInventoryBuilder>{
  public AWSPrivateLinkInventoryBuilder() {
    this(false);
  }
  public AWSPrivateLinkInventoryBuilder(Boolean validationEnabled) {
    this(new AWSPrivateLinkInventory(), validationEnabled);
  }
  public AWSPrivateLinkInventoryBuilder(AWSPrivateLinkInventoryFluent<?> fluent) {
    this(fluent, false);
  }
  public AWSPrivateLinkInventoryBuilder(AWSPrivateLinkInventoryFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AWSPrivateLinkInventory(), validationEnabled);
  }
  public AWSPrivateLinkInventoryBuilder(AWSPrivateLinkInventoryFluent<?> fluent,AWSPrivateLinkInventory instance) {
    this(fluent, instance, false);
  }
  public AWSPrivateLinkInventoryBuilder(AWSPrivateLinkInventoryFluent<?> fluent,AWSPrivateLinkInventory instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new AWSPrivateLinkInventory());

    if (instance != null) {
      fluent.withRegion(instance.getRegion());
      fluent.withSubnets(instance.getSubnets());
      fluent.withVpcID(instance.getVpcID());
      fluent.withRegion(instance.getRegion());
      fluent.withSubnets(instance.getSubnets());
      fluent.withVpcID(instance.getVpcID());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AWSPrivateLinkInventoryBuilder(AWSPrivateLinkInventory instance) {
    this(instance,false);
  }
  public AWSPrivateLinkInventoryBuilder(AWSPrivateLinkInventory instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new AWSPrivateLinkInventory());

    if (instance != null) {
      this.withRegion(instance.getRegion());
      this.withSubnets(instance.getSubnets());
      this.withVpcID(instance.getVpcID());
      this.withRegion(instance.getRegion());
      this.withSubnets(instance.getSubnets());
      this.withVpcID(instance.getVpcID());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AWSPrivateLinkInventoryFluent<?> fluent;
  Boolean validationEnabled;
  public AWSPrivateLinkInventory build() {
    AWSPrivateLinkInventory buildable = new AWSPrivateLinkInventory(fluent.getRegion(),fluent.buildSubnets(),fluent.getVpcID());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
